export declare enum Direction {
    In = "in",
    Inout = "inout",
    Out = "out"
}
export interface GirXML {
    repository: Repository[];
}
declare type UnparsedNumber = string;
declare type BinaryOption = "0" | "1";
export interface Repository {
    $: {
        version?: string;
        "c:identifier-prefixes"?: string;
        "c:symbol-prefixes"?: string;
    };
    include: Include[];
    "c:include": CInclude[];
    package: Package[];
    namespace: Namespace[];
}
export interface Namespace {
    $: InfoAttrs & {
        name: string;
        version: string;
        "c:identifier-prefixes"?: string;
        "c:symbol-prefixes"?: string;
        "c:prefix"?: string;
        "shared-library"?: string;
    };
    alias?: AliasElement[];
    class?: ClassElement[];
    interface?: InterfaceElement[];
    record?: RecordElement[];
    enumeration?: EnumElement[];
    function?: FunctionElement[];
    union?: UnionElement[];
    bitfield?: BitfieldElement[];
    callback?: CallbackElement[];
    constant?: ConstantElement[];
    annotation?: Annotation[];
    ["glib:boxed"]?: BoxedElement[];
}
export interface Annotation {
    $: {
        name: string;
        value: string[];
    };
}
export interface CInclude {
    $: {
        name: string;
    };
}
export interface Include {
    $: {
        name: string;
        version?: string;
    };
}
export interface Package {
    $: {
        name: string;
    };
}
export interface AliasElement extends InfoElements {
    $: InfoAttrs & {
        name: string;
        "c:type": string;
    };
    type: Type[];
}
export interface InterfaceElement extends InfoElements {
    $: {
        name: string;
        "glib:type-name": string;
        "glib:get-type": string;
        "c:symbol-prefix"?: string;
        "c:type"?: string;
        "glib:type-struct"?: string;
    };
    prerequisite?: Prerequisite[];
    implements?: Implements[];
    function?: FunctionElement[];
    constructors?: ConstructorElement[];
    method?: MethodElement[];
    "virtual-method"?: VirtualMethodElement[];
    field?: FieldElement[];
    property?: PropertyElement[];
    signal?: SignalElement[];
    callback?: CallbackElement[];
    constant?: ConstantElement[];
}
export interface ClassElement extends InfoElements {
    $: InfoAttrs & {
        name: string;
        "glib:type-name": string;
        "glib:get-type": string;
        parent?: string;
        "glib:type-struct"?: string;
        "glib:ref-func"?: string;
        "glib:unref-func"?: string;
        "glib:set-value-func"?: string;
        "glib:get-value-func"?: string;
        "c:type"?: string;
        "c:symbol-prefix"?: string;
        abstract?: BinaryOption | BinaryOption;
        "glib:fundamental"?: BinaryOption | BinaryOption;
    };
    implements?: Implements[];
    "constructor"?: ConstructorElement[];
    method?: MethodElement[];
    function?: FunctionElement[];
    "virtual-method"?: VirtualMethodElement[];
    field?: FieldElement[];
    property?: PropertyElement[];
    signal?: SignalElement[];
    union?: UnionElement[];
    constant?: ConstantElement[];
    record?: RecordElement[];
    callback?: CallbackElement[];
}
export interface BoxedElement {
    $: InfoAttrs & {
        "glib:name": string;
        "c:symbol-prefix"?: string;
        "glib:type-name"?: string;
        "glib:get-type"?: string;
    };
    function?: FunctionElement[];
}
export interface RecordElement extends InfoElements {
    $: InfoAttrs & {
        name: string;
        "c:type"?: string;
        disguised?: BinaryOption | BinaryOption;
        "glib:type-name"?: string;
        "glib:get-type"?: string;
        "c:symbol-prefix"?: string;
        foreign?: BinaryOption | BinaryOption;
        "glib:is-gtype-struct-for"?: string;
    };
    field?: FieldElement[];
    function?: FunctionElement[];
    union?: UnionElement[];
    method?: MethodElement[];
    "constructor"?: ConstructorElement[];
    property?: PropertyElement[];
}
export interface InfoAttrs {
    introspectable?: BinaryOption | BinaryOption;
    deprecated?: string;
    "deprecated-version"?: string;
    version?: string;
    stability?: string[];
}
export interface DocElement {
    "doc-version"?: [
        {
            $: {
                "xml:space"?: "preserve";
                "xml:whitespace"?: "preserve";
            };
            _: string;
        }
    ];
    "doc-stability"?: [
        {
            $: {
                "xml:space"?: "preserve";
                "xml:whitespace"?: "preserve";
            };
            _: string;
        }
    ];
    doc: [
        {
            $: {
                "xml:space"?: "preserve";
                "xml:whitespace"?: "preserve";
                filename: string;
                line: string;
                column: string;
            };
            _: string;
        }
    ];
    "doc-deprecated": [
        {
            $: {
                "xml:space"?: "preserve";
                "xml:whitespace"?: "preserve";
            };
            _: string;
        }
    ];
    "source-position": [
        {
            filename: string;
            line: string;
            column: string[];
        }
    ];
}
export interface InfoElements extends DocElement {
    annotation: Annotation[];
}
export interface ConstantElement extends InfoElements, AnyType {
    $: InfoAttrs & {
        name: string;
        value: string;
        "c:type"?: string;
        "c:identifier"?: string;
    };
}
export interface PropertyElement extends InfoElements, AnyType {
    $: InfoAttrs & {
        name: string;
        writable?: BinaryOption | BinaryOption;
        readable?: BinaryOption | BinaryOption;
        construct?: BinaryOption | BinaryOption;
        "construct-only"?: BinaryOption | BinaryOption;
        TransferOwnership?: any;
    };
}
export interface SignalElement extends InfoElements {
    $: InfoAttrs & {
        name: string;
        detailed?: BinaryOption | BinaryOption;
        when?: "first" | "last" | "cleanup";
        action?: BinaryOption | BinaryOption;
        "no-hooks"?: BinaryOption | BinaryOption;
        "no-recurse"?: BinaryOption | BinaryOption;
    };
    parameters?: [CallableParams];
    "return-value"?: CallableReturn[];
}
export interface FieldElement extends InfoElements, AnyType {
    $: InfoAttrs & {
        name: string;
        writable?: BinaryOption | BinaryOption;
        readable?: BinaryOption | BinaryOption;
        private?: BinaryOption | BinaryOption;
        bits?: UnparsedNumber;
    };
    callback?: CallbackElement[];
}
export interface CallbackElement extends InfoElements {
    $: InfoAttrs & {
        name: string;
        "c:type"?: string;
        throws?: BinaryOption | BinaryOption;
    };
    parameters?: [CallableParams];
    "return-value"?: CallableReturn[];
}
export interface Implements {
    $: InfoAttrs & {
        name: string;
    };
}
export interface Prerequisite {
    $: InfoAttrs & {
        name: string;
    };
}
export interface AnyType {
    type?: Type[];
    array?: ArrayType[];
}
export interface Type extends DocElement {
    $: InfoAttrs & {
        name?: string;
        "c:type"?: string;
        introspectable?: BinaryOption | BinaryOption;
    };
    array?: ArrayType[];
    type: Type[];
}
export interface ArrayType {
    $: InfoAttrs & {
        name?: string;
        "zero-terminated"?: BinaryOption | BinaryOption;
        "fixed-size"?: UnparsedNumber;
        introspectable?: BinaryOption | BinaryOption;
        length?: UnparsedNumber;
        "c:type"?: string;
    };
    array?: ArrayType[];
    type?: Type[];
}
export declare enum TransferOwnershipType {
    Container = "container",
    Full = "full",
    None = "none"
}
export interface TransferOwnership {
    "transfer-ownership": TransferOwnershipType;
}
export interface ConstructorElement {
    $: InfoAttrs & CallableAttrs;
    parameters?: [CallableParams];
    "return-value"?: CallableReturn[];
}
export interface CallableAttrs {
    name: string;
    "c:identifier"?: string;
    "shadowed-by"?: string;
    shadows?: string;
    throws?: BinaryOption | BinaryOption;
    "moved-to"?: string[];
}
export interface VarArgs {
    $: InfoAttrs;
}
export interface CallableParamElement extends DocElement, AnyType {
    $: InfoAttrs & Partial<TransferOwnership> & {
        name?: string;
        nullable?: BinaryOption | BinaryOption;
        "allow-none"?: BinaryOption | BinaryOption;
        introspectable?: BinaryOption | BinaryOption;
        closure?: UnparsedNumber;
        destroy?: UnparsedNumber;
        scope?: "notified" | "async" | "call";
        direction?: Direction;
        "caller-allocates"?: BinaryOption | BinaryOption;
        optional?: BinaryOption | BinaryOption;
        skip?: BinaryOption | BinaryOption;
    };
    varargs?: VarArgs[];
}
export interface CallableParams {
    parameter: CallableParamElement[];
    "instance-parameter"?: AnyType & {
        $: Partial<{
            name: string;
            nullable?: BinaryOption | BinaryOption;
            "allow-none"?: BinaryOption | BinaryOption;
            direction?: Direction;
            "caller-allocates"?: BinaryOption | BinaryOption;
        }> & Partial<TransferOwnership>;
    }[];
}
export interface CallableReturn extends AnyType, DocElement {
    $: {
        introspectable?: BinaryOption | BinaryOption;
        nullable?: BinaryOption | BinaryOption;
        closure?: UnparsedNumber;
        scope?: "notified" | "async" | "call";
        destroy?: UnparsedNumber;
        skip?: BinaryOption | BinaryOption;
        "allow-none"?: BinaryOption | BinaryOption;
    } & Partial<TransferOwnership>;
}
export interface FunctionElement extends DocElement {
    $: InfoAttrs & CallableAttrs;
    parameters?: [CallableParams];
    "return-value"?: CallableReturn[];
}
export interface MethodElement extends DocElement {
    $: InfoAttrs & CallableAttrs;
    parameters?: [CallableParams];
    "return-value"?: CallableReturn[];
}
export interface VirtualMethodElement extends DocElement {
    $: InfoAttrs & CallableAttrs & {
        invoker?: string;
    };
    parameters?: [CallableParams];
    "return-value"?: CallableReturn[];
}
export interface UnionElement extends InfoElements {
    $: InfoAttrs & {
        name?: string;
        "c:type"?: string;
        "c:symbol-prefix"?: string;
        "glib:type-name"?: string;
        "glib:get-type"?: string;
    };
    field?: FieldElement[];
    "constructor"?: ConstructorElement[];
    method?: MethodElement[];
    function?: FunctionElement[];
    record?: RecordElement[];
}
export interface BitfieldElement extends InfoElements {
    $: InfoAttrs & {
        name: string;
        "c:type": string;
        "glib:type-name"?: string;
        "glib:get-type"?: string;
    };
    member: MemberElement[];
    function: FunctionElement[];
}
export interface EnumElement extends InfoElements {
    $: InfoAttrs & {
        name: string;
        "c:type": string;
        "glib:type-name"?: string;
        "glib:get-type"?: string;
        "glib:error-domain"?: string;
    };
    member?: MemberElement[];
    function?: FunctionElement[];
}
export interface MemberElement extends InfoElements {
    $: InfoAttrs & {
        name: string;
        value: string;
        "c:identifier": string;
        "glib:nick"?: string;
    };
}
export {};
